.. _encoding_a_column_ref:
.. currentmodule:: skrub

Encoding a column
=================

.. autosummary::
   :toctree: generated/
   :template: class.rst
   :nosignatures:

   GapEncoder
   MinHashEncoder
   SimilarityEncoder
   DatetimeEncoder
   ToCategorical
   ToDatetime

.. autosummary::
   :toctree: generated/
   :template: function.rst
   :nosignatures:

   to_datetime
